@@ -1,10 +1,10 @@
 
 from .basic import DependencyGraph, Variable, compute_sequential, Stopwatch, \
-        print_value, assign
+        print_value, assign, source, is_source
 
 from .aio import async_compute_sequential, async_compute_concurrent, \
         async_compute_concurrent_simple, timer
 
 from .mod import ModClock, ModVariable, ModPrinter
 
-from .flow import compute_flow, repeat
+from .flow import compute_flow
